[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Review

# Which factors differentiate athletes with hip/groin pain from those without? A systematic review with meta-analysis

### Andrea B Mosler, \[1,2\] Rintje Agricola, \[3\] Adam Weir, \[4\] Per Hölmich, \[4,5\] Kay M Crossley \[2,6\]

- Additional material is
  published online only. To view
  please visit the journal online
  [(http://dx.doi.org/10.1136/](http://dx.doi.org/10.1136/bjsports-2015-094602)
  [bjsports-2015-094602).](http://dx.doi.org/10.1136/bjsports-2015-094602)

1Rehabilitation Department,
Aspetar Orthopaedic and
Sports Medicine Hospital,
Doha, Qatar
2School of Health and
Rehabilitation Sciences,
University of Queensland,
Brisbane, Australia
3Department of Orthopaedics,
Erasmus University Medical
Centre, Rotterdam,
the Netherlands
4Sports Groin Pain Centre,
Aspetar Orthopaedic and
Sports Medicine Hospital,
Doha, Qatar
5Arthroscopic Center Amager,
SORC-C, Copenhagen
University Hospital,
Amager-Hvidovre, Denmark
6School of Allied Health,
La Trobe University, Victoria,
Australia

Correspondence to
Professor Kay M Crossley,
School of Allied Health,
College of Science, Health and
Engineering, La Trobe
University, Bundoora, Victoria
3068, Australia;
<k.crossley@latrobe.edu.au>

Accepted 4 April 2015

Open Access
Scan to access more
free content

To cite: Mosler AB,
Agricola R, Weir A, et al. Br
J Sports Med 2015;49:810.

ABSTRACT
Background Hip and groin injuries are common in
many sports. Understanding the factors differentiating
athletes with hip/groin pain from those without these
injuries could facilitate management and prevention.
Objective Conduct a systematic review and metaanalysis of the literature on factors differentiating
athletes with and without hip/groin pain.
Methods The review was registered as PROSPERO
CRD42014007416 and a comprehensive, systematic
search was conducted in June 2014. Inclusion criteria

–
were: cross-sectional, cohort or case control study
designs of n>10 that examined outcome measures
differentiating athletes with and without hip/groin pain.
Two authors independently screened search results,
assessed study quality, and performed data extraction.
Methodological heterogeneity was determined and data
pooled for meta-analysis when appropriate. A best
evidence synthesis was performed on the remaining
outcome measures.
Results Of 2251 titles identified, 17 articles were
included of which 10 were high quality. Sixty two
different outcome measures were examined, 8
underwent meta-analysis. Pooled data showed strong
evidence that athletes with hip/groin pain demonstrated:
pain and lower strength on the adductor squeeze test,
reduced range of motion in hip internal rotation and
bent knee fall out; however, hip external rotation range
was equivalent to controls. Strong evidence was found
that lower patient-reported outcome (PRO) scores,
altered trunk muscle function, and moderate evidence of
bone oedema and secondary cleft sign were associated
with hip/groin pain.
Conclusions PROs, pain and reduced strength on the
adductor squeeze test, reduced range of motion in
internal rotation and bent knee fall out are the outcome
measures that best differentiate athletes with hip/groin
pain from those without this pain.

INTRODUCTION
Hip and groin pain is problematic for athletes, particularly in sports involving high loads of running,
change of direction and kicking. Groin pain is the
third most common injury in both soccer and
Australian Rules football, accounting for 4–16% of
all injuries sustained per season. \[1 2\] It is also frequent in other football codes, such as Rugby
League, \[3\] Gaelic Football \[4\] 5 and American
Football, \[6\] as well as ice hockey. \[7\] The aetiology is
multifactorial, with coexisting pathological processes occurring in different tissues. \[8\]\[–\]\[11\] Varying
approaches have been recommended to systematically examine and diagnose groin pain in an

athlete. \[11\]\[–\]\[13\] While the reliability of the tests used
in these approaches has been examined, \[14\]\[–\]\[16\] there
remains a lack of consensus on the terminology and
diagnostic categories used.
Intrinsic risk factors for hip/groin pain in athletes
have been prospectively studied. \[3 17\]\[–\]\[23\] Two systematic reviews identified only past history of injury
and lower adductor strength as risk factors, while
there is conflicting evidence for reduced hip range
of motion. \[4\] 24 Injury prevention programmes
aimed at reducing the incidence of groin pain by
addressing these potentially modifiable risk factors
have had limited efficacy. \[25\]\[–\]\[28\] Hip and groin pain
still has a high incidence and recurrence rate. \[17 23\]

Therefore, it seems that we do not yet fully understand these injuries and further research is required
to assist in the understanding of injury mechanisms,
and factors contributing to the development of hip/
groin pain.
Injury prevention and management programmes
may be enhanced by knowledge of the factors differentiating athletes with and without hip/groin
pain. Previous case–control and cohort studies
have examined the relationship between hip/
groin pain, and various clinical and radiological
features. \[5 15\]\[–\]\[17 22 29\]\[–\]\[42\] A systematic evaluation of
this literature may assist in the management and
prevention of this common athletic injury.
This study aimed to systematically review the literature examining the factors differentiating athletes with and without hip/groin pain.

METHODS
This review followed the PRISMA guidelines and
the protocol was registered on the PROSPERO
International prospective register for systematic reviews
[website (http://www.crd.york.ac.uk/PROSPERO) on 9](http://www.crd.york.ac.uk/PROSPERO)
April 2014, with the following registration
number: CRD42014007416.

Eligibility criteria

–
Inclusion criteria were (1) case control, cohort and
cross-sectional study designs, and (2) study of at
least one factor differentiating between athletic subjects with hip/groin pain and those without. Hip/
groin pain participants were defined as those identified with having pain in the hip and groin region,
and encompassed the many different terminologies
used to describe athletic groin pain such as osteitis
pubis, long-standing groin pain, pubalgia, adductorrelated groin pain, and hip joint pain. Athletic
populations included people who participated in
any of the sports included under the MESH term
‘sports’ plus marathon running. No restrictions

Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602 1 of 12

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Review

were placed on the duration of participant symptoms. In order
to reduce the potential risk of bias, a minimum number of 10
cases of hip/groin pain and control subjects were required.
Studies written in English, Dutch, German, Italian, French or
Spanish were included. Studies without a control group were
excluded from the review.

Search strategy
A comprehensive, systematic literature search was conducted on
20 June 2014, using the following electronic databases with no
date restrictions (1) EMBASE.com (2) MEDLINE (OvidSP) (3)
Cochrane (4) Web-of-science (5) Scopus (6) Cinahl (7) PubMed
publisher (8) Google Scholar and (9) Sport Discus. The complete electronic search strategy is available in online supplementary material A. The literature search was assisted by a
biomedical information specialist (W.M. Bramer, Erasmus
University). The following key words were used for the search
with differing combinations: ‘hip’, ‘inguinal’, ‘groin’, ‘pubalgia’,
‘pain’, ‘sport’, ‘team sport’, ‘sport injury’, ‘sports medicine’,
‘athlete’, ‘athletic performance’ plus the MESH term ‘sports’
plus marathon running. Search strategies were adapted as
required for each specific database
All potential references were imported into Endnote X4
(Thomson Reuters, Carlsbad, California, USA) and duplicates
removed. Title and abstracts were independently screened for
eligibility by two authors (ABM and RA). The full text of each
eligible published study was then independently examined given
the inclusion criteria and reference lists manually searched to
identify further relevant articles.

Quality appraisal
Two reviewers (ABM and RA) independently conducted methodological quality assessment on each included article using the
modified Downs and Black scale (see online supplementary B),

–
which is appropriate for cohort and case control study designs.
The Downs and Black scale is reliable \[43\] and the modified
version used in this study had a maximum score of 16. \[44 45\] The
methodological quality of each article was stratified, as in previous reviews, \[45\] with a total score ≥12 deemed to be high quality,
10 or 11 to be moderate quality, and low quality if the score
was ≤9. Disagreements in initial ratings of methodological
quality assessment were discussed between the two reviewers
(ABM, RA) and if required, a third reviewer (KMC) was consulted to reach consensus.

Data extraction
All data from the included studies were independently extracted,
collated by consensus agreement, and entered into a predefined
Excel spread sheet by two reviewers (ABM, RA). If sufficient
data were not reported in the published article or online
[supplementary material provided, the corresponding author was](http://bjsm.bmj.com/lookup/suppl/doi:10.1136/bjsports-2015-094602/-/DC1)
contacted to request further data.
Study data were subdivided into the following categories:
patient reported outcome (PRO) measures, pain provocation
tests, range of motion, strength, trunk muscle function, radiological measures, and other outcome measures.

Data synthesis and analysis
Data extraction of the included studies was conducted with
means and SDs calculated for continuous data for the hip/groin
and control participants separately. If data were not presented in
a manner enabling extraction, the corresponding author was

contacted to obtain the raw data. Where separate data were presented for both legs of control subjects; an average mean and
SD was calculated. For the case groups, data from the symptomatic leg were used if available or a mean (SD) of data from both
legs calculated if participants had bilateral symptoms or if the
symptomatic leg could not be determined. If more than one
method of measurement was used for a single outcome
measure, the data were extracted from the method used most
consistently between studies and/or determined to be most
reliable.
Methodological and clinical heterogeneity was evaluated for
all outcome measures and data pooled for meta-analysis as
appropriate. The software package from Review Manager
(RevMan) Version 5.3, Copenhagen: The Nordic Cochrane
Centre, The Cochrane Collaboration, 2014, was used to
conduct the meta-analysis. Standardised mean differences
(SMD) with 95% CIs were calculated for outcome measures of
continuous data and random effects models were used for each
meta-analysis. The magnitude of the effect size of the pooled
SMD was interpreted as large if SMD ≥0.8; moderate if 0.5–
0.8; weak if 0.2–0.5, and no effect determined if SMD≤0.2. \[46\]

Statistical heterogeneity of the pooled data was examined
using the I \[2\] statistic. Sensitivity analysis was conducted by examining the forest plots of the pooled data following omission of
the data from each study, one by one.
For dichotomous data, an OR was calculated for the association between a positive test and the presence of hip and groin
pain, and data pooled if methodological homogeneity was determined. Effect sizes for the OR were defined as follows: small
effect OR=1–1.25, medium effect OR=1.25–2 and large effect
OR≥2. \[47\]

For outcome measures with methodological or clinical heterogeneity, qualitative data synthesis and analysis was performed.
For both quantitative and qualitative data synthesis, a level of
evidence was assigned to each outcome according to the recommendations proposed by van Tulder et al. \[48\]

RESULTS

Literature search
The electronic search identified 5269 records and following
removal of duplicates, the titles and abstracts of 2251 articles
were screened. The full text of 41 articles were retrieved and
assessed for eligibility against the inclusion criteria. Two articles
were added following citation checking. \[36 37\] After reviewing the
full text of 43 articles, 26 articles were excluded and the
remaining 17 articles \[5 15 16 30\]\[–\]\[33 35\]\[–\]\[40 50\]\[–\]\[53\] were included for
full review and data synthesis (figure 1).

Methodological quality
Two reviewers (ABM and RA) initially disagreed upon 21% of
the items of the 17 included studies (54 of 255 items).
However, all initial disagreements were discussed and consensus
reached on a final score for each paper, using the assistance of a
third reviewer (KMC) where required. The methodological
quality scores ranged from 8 to 15 out of maximum possible
score of 16, with the average score being 12 (see online supplementary table S1). Ten of the included studies were of high
quality, 6 were of moderate quality and only 1 low quality study
was included for final data synthesis. Three studies scored positively on item 14 (sample size calculation) while 7 studies
reported blinding of assessors with respect to the presence of
hip/groin pain of the subjects (item 8).

2 of 12 Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Figure 1 Flow diagram for search
results and study selection.

Review

Characteristics of included studies
Table 1 presents the full characteristics of the included studies.
Data extraction was performed on all 17 of the included studies
and a detailed description of the studies is presented regarding
authors, year of publication, study design, participants (case and
control), diagnosis, symptom duration, outcome measure(s)
examined, method of measurement, differences between case
and control.

Factors differentiating athletes with and without hip/groin pain
Patient reported outcome measures
Several studies presented data from PROs, completed by both
control and hip/groin pain athletes. \[5 30 31 36 52\] None used identical PROs, but three high-quality studies assessed aspects of
pain using a Likert scale. \[30 31 36\] The Copenhagen hip and groin
outcome score (HAGOS) was used in one high-quality study, \[5\]

while another high–quality study \[52\] used both the short form
(SF)-12, and the Hip Disability and Osteoarthritis Outcome
Score (HOOS). The results of the PROs are summarised in table 2.
All PROs were able to differentiate between athletes with and
without hip/groin pain, apart from the mental component
summary (MCS) of the SF-12. Synthesising these findings, there
is strong evidence that PROs can be used to differentiate athletes
with and without hip/groin pain.

Pain provocation tests
Five studies examined the difference between athletes with and
without hip/groin pain in response to various pain provocation
tests. \[16 30 35 36 53\] The pain on adductor squeeze testing was
recorded by 3 high-quality studies using the same methodology
(supine, resisted adduction at the medial knee with hips at 45°
flexion, and knees flexed 90°). \[16 30 53\] One of these studies \[30\]

reported significantly greater pain experienced during the
squeeze test in the hip/groin pain group (p\<0.001). However,
information on the number of groin pain athletes who experienced pain with the squeeze test was not presented; therefore,
the data from this study could not be pooled. Data pooling
from the other 2 studies revealed a greater chance of being in
the hip/groin pain group if participants experienced pain during
the squeeze test with a large effect size; OR=4.31 (95% CI
1.86 to 10) figure 2. There is, therefore, strong evidence that
pain on the adductor squeeze test differentiates athletes with
hip/groin pain from those without pain.
The ORs for the other pain provocation tests examined in
single studies are: single adductor test (supine, leg straight and

–
resisted adduction at the ankle): \[16\] OR=4.03 (1.21 13.45), bilateral adductor test (resisted bilateral adduction while athlete holds

–
both legs off the bed in 30° hip flexion): \[16\] OR=24.76 (5.35

–
114.6), active straight leg raise test: \[36\] OR=56.64 (3.27 980.14),

Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602 3 of 12

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Review

–
pelvic belt test: \[36\] OR=187.21 (3.27 980.14), impingement
test: \[35\] OR=50.62 (11.3–226.73).
The active straight leg raise test was also examined in an additional high-quality study, \[30\] but despite the authors finding a
statistically significant difference between the control and hip/
groin pain subjects for this test (p=0.001), the mean of the

–
control group was 0 (0 0) and for the hip/groin pain group this

–
was also 0 (0 4), consequently an OR could not be calculated.
Despite the high-diagnostic ORs for the single adductor, bilateral adductor, active straight leg raise, pelvic belt, and impingement tests, the results demonstrated in single studies show that
there is currently limited evidence that these tests differentiate
between hip/groin pain athletes from those without pain.

Range of motion
Five studies examined hip range of motion, including the variables of hip internal and external rotation, and bent knee fall
out. \[5 15 33 35 53\]

Hip internal rotation (IR) was measured in prone with
the hip in neutral flexion/extension in 3 high-quality studies
(figure 3). \[5 15 53\] The meta-analysis revealed strong evidence that
hip IR range in prone is less in athletes with hip and groin pain

–
SMD=0.42 (0.01 0.83) than those without pain. The difference in range between the two groups equated to an average of

–
3.7° (1.1 6.3°) of reduced hip IR in the athletes with pain,
which represents a weak effect.
Hip IR was measured in supine with the hip and knee at 90°
flexion in 2 moderate quality studies. \[33 35\] Meta-analysis provided moderate evidence that hip IR range measured in supine

–
was less in athletes with hip/groin pain; SMD=0.58 (0.14 1.01)
figure 4. This moderate effect equated to an average of 3.83°

–
(0.31 7.75°) of reduced hip IR in the athletes with pain.
External rotation (ER) was measured in supine with the hip
in neutral flexion/extension in three high-quality studies, \[5 15 53\]

and in supine with the hip in 90° flexion in 1 moderate quality
study. \[33\] The data was pooled for the three studies with neutral
flexion/extension (figure 5). There was strong evidence that hip
ER range of motion did not differentiate hip/groin pain athletes

−
from those without pain; SMD=0.18 ( 0.55 to 0.19). In the
single study \[33\] with hip ER measured in 90° flexion, a weak
effect size was present between the hip/groin pain group and

–
control groups; SMD=0.47 (0.04 0.89). This difference in

–
range equates to 2.55° (0.31 4.79°), and provided limited evidence that reduced hip ER range measured in 90° flexion was
associated with hip/groin pain in athletes.
Bent knee fall out (BKFO) is a combined movement of hip
flexion, abduction and external rotation, and was examined in
two high-quality studies, \[5 15\] Meta-analysis was possible as identical measurement methods were used. There was strong evidence that a higher score on bent knee fall out, representing
reduced range of motion for this test, differentiates athletes with

–
hip/groin pain from those without pain; SMD=0.75 (0.24 1.27)

–
figure 6. This moderate effect equates to 3.6 cm (1.3 5.8 cm).

Strength
Strength on the adductor squeeze test measured at 45° hip
flexion, was examined quantitatively in five studies. \[5 15 30 36 53\]

Data were available for four of these studies, and the pooled
data (figure 7) demonstrated strong evidence that the presence of
hip/groin pain was associated with less strength on adductor

–
squeeze testing. The effect size was large; SMD=1.41 (0.44 2.37).
The magnitude of the difference between the case and
control groups varied between the studies as represented by the
high statistical heterogeneity I \[2\] =89%. Separating the data into

6 of 12 Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Figure 2 Forest plot demonstrating the odds ratio of pain with the adductor squeeze test.

Review

common measurement units, the standardised mean difference

–
between case and control equates to 49 mm Hg (12 85 mm Hg)

–
and 53N (24 83N).
One high quality study also examined isometric abduction
strength using a hand-held dynamometer, in supine with neutral
hip flexion/extension. \[15\] There was no difference between the

–
hip/groin pain group and the controls for either leg (p=0.71
0.84). Another high-quality study used an isokinetic dynamometer to compare hip abduction, adduction, flexion, and extension strength. \[51\] In this study, only hip flexion strength was
significantly different (higher) in the hip/groin pain group compared with controls (p=0.028). Similarly, the ratio of hip
flexors/extensors was significantly higher in the hip/groin pain
group compared to the controls (p=0.02). Therefore, there is
limited evidence that when using an isokinetic dynamometer,
hip flexion strength is greater in hip/groin pain participants than
controls, but abduction, adduction and extension strength are
similar.

Trunk muscle function
Trunk muscle function was measured in three high-quality
studies, \[30 31 50\] Table 1. The methodologies and outcome measures were distinctly heterogeneous, precluding meta-analysis.
The first study investigated electromyography activity of transversus abdominus, obliquus internus and externus and rectus
femoris during an active straight leg raise task. \[31\] The onset of
transversus abdominus activity relative to rectus femoris was
found to be delayed in the hip/groin pain group in comparison
to controls (p≤0.05). There was no significant difference
between the onset timing for the other muscles relative to rectus
femoris. Another study \[30\] used ultrasound measurements to
compare the thickness of tranversus abdominis and obliquus
internus (as a measure of muscle recruitment capacity) at rest,
and during both the active straight leg raise task and adductor

squeeze test. The hip/groin pain participants had a significantly
thinner transversus abdominis (p=0.015) compared to controls
when measured at rest, though no difference was found in obliquus internus thickness (p≥0.05). During both the active
straight leg raise and adductor squeeze test, the thickness of
both muscles was not significantly different between groups
(p≥0.15).
Isokinetic dynamometry was used in another high-quality
study to examine abdominal and back extensor muscle
strength. \[50\] A significantly lower concentric back (p=0.001) and

```
                                      eccentric abdominal (p=0.005) muscle strength, and signifi
```

cantly greater concentric abdominal/back extensor ratio
(p=0.019) was found in the hip/groin pain group compared to
the control group. There were no significant between-group differences found for eccentric back and concentric abdominal
muscle strength (p>0.05), or eccentric abdominal/back extensor
ratio (p>0.05). Although these 3 studies examined different
aspects of trunk muscle function, synthesis of these findings
showed strong evidence that trunk muscle function is altered in
athletes with hip/groin pain compared to athletes without pain.

Radiological
One low quality study used X-ray to examine the pubic symphyses of athletes with hip/groin pain and those without pain. \[39\]

A reliable grading system quantified the abnormalities, which
were present in all the hip/groin pain subjects (9/20 slight, 9/20
intermediate, 2/20 advanced). In contrast, the athletic control
subjects had either no (3/20) or slight (17/20) abnormalities
seen on X-ray. Another moderate quality study only reported
the radiographic findings in the hip/groin pain subjects and not
the control subjects. \[37\] Synthesising the data on X-ray investigations of the pubic symphysis, there is currently limited evidence
that X-ray findings differentiate athletes with hip/groin pain
from athletes without pain.

Figure 3 Forest plot: association between hip/groin pain and hip internal rotation range of motion measured with neutral flexion/extension.

Figure 4 Forest plot: association between hip/groin pain and hip internal rotation range of motion measured with 90° hip and knee flexion.

Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602 7 of 12

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Review

Figure 5 Forest plot: association between hip/groin pain and hip external rotation range of motion measured with neutral flexion/extension.

Three moderate quality studies examined pubic bone oedema
using MRI in athletes with hip/groin pain and controls. \[32 38 40\]

Dichotomous data for the presence or absence of bone oedema
were extracted and pooled from these studies (figure 8).
The results indicated that there were high odds that participants
with bone oedema on MRI would be in the hip/groin pain

–
group with a large effect size; OR=41.63 (1.6 1096.60).
However, there was high heterogeneity demonstrated by this
pooled result (I \[2\] =88%), and significant sensitivity to the data
from the study of Cunningham et al \[38\] Figures 8 and 9. The

–
removal of this study data resulted in an OR of 8.1 (3.1 21.2)
for the presence of bone oedema in subjects with hip/groin
pain, representing moderate evidence, with a large effect size,
that bone oedema in the pubic symphysis differentiates athletes
with hip/groin pain from those without this pain.
The presence of the secondary cleft sign was also examined in
2 moderate quality studies \[37 38\] and the data were pooled for
this outcome measure (figure 10). Meta-analysis showed a
strong association between the presence of the secondary cleft

–
sign and hip/groin pain OR=638.8 (82.9 4925.5). Indeed,
there was an absence of this sign on pubic symphysis MRI
examination of 170 athletic controls. These 2 studies provide
moderate evidence that the presence of the secondary cleft sign
differentiates athletes with and without hip/groin pain.
Other abnormalities were reported by 4 MRI studies. \[32 37 38 40\]

However, inconsistent methods of reporting and analysis of these
abnormalities precluded data synthesis.
One moderate quality cohort study investigated the radiological signs of femoroacetabular impingement (FAI). \[35\] This
study used MRI of the hip to determine whether higher α
angles correlated with the presence of symptomatic hips.
Athletes with symptomatic hips were found to have significantly
higher α angles when measured at the 12, 1 and 2 o’clock positions (corresponding to the anterolateral head-neck junction)
(p\<0.022), but not at the 9, 10, 11 or 3 o’clock positions

–
(p=0.181 0.602). This means that there is currently limited evidence that the radiological signs of FAI differentiate athletes
with hip/groin pain from those without these symptoms.

Other outcome measures
Biomarkers of cartilage damage and inflammation circulating in
the blood were examined in one high-quality study, \[52\] Table 1.
The biomarkers examined were cartilage oligomeric matrix
protein (COMP) and C reactive protein (CRP). COMP is a connective tissue extracellular matrix protein that is a marker of

cartilage turnover, and increased levels of COMP are associated
with joint inflammation and OA. \[52\] CRP is another biological
marker that is associated with inflammation. Athletes with
symptomatic FAI had a 24% increase (p=0.04) in circulating
levels of COMP and a 276% increase (p\<0.001) in circulating
levels of CRP. Therefore, there is limited evidence that the biomarkers for cartilage degradation and inflammation are elevated
in athletic males with hip/groin pain compared to controls.

DISCUSSION
This review systematically identified factors for differentiating
athletes with or without hip/groin pain. Of the 17 studies
included for data synthesis, 10 were of high quality, 6 moderate
and 1 low quality. A total of 62 variables were examined, with
meta-analysis performed for 8 of these variables. There is strong
evidence that the following variables differentiate athletes with
hip/groin pain from those without: PROs, pain on adductor
squeeze test, hip IR, bent knee fall out, adductor squeeze
strength, and trunk muscle function. Hip IR range of motion
measured in flexion differentiates painful athletes with a larger
effect size than when hip IR is measured in neutral. There is
moderate evidence that the presence of pubic symphysis bone
oedema and the secondary cleft sign are more common in athletes with hip/groin pain. There is limited evidence that hip ER
measured in flexion differentiates between athletes with and
without hip/groin pain, and strong evidence that this movement
did not differ when measured in neutral. The low number of
studies comparing athletes with hip/groin pain to those without
hip/groin pain, using the following outcome measures: pain
provocation tests (apart from the squeeze test), X-ray abnormalities of the pubic symphysis, radiological features of FAI, and
biomarkers of cartilage degradation, means that currently there
is only limited evidence supporting the association of these
outcome measures with the presence of hip/groin pain. The
findings of this review do not, however, indicate how well each
of the various clinical and radiological tests can determine the
presence of individual diagnostic categories.
The PROs used in the included studies were inconsistent, precluding meta-analysis. Furthermore, in some case–control
studies, PROs were used to exclude symptomatic athletes from
control groups. \[30 31 36\] Impairments in PROs ranged from 0 to
55%, suggesting that further cross-sectional and cohort studies
should use valid, reliable and consistent PROs to enable comparisons between studies.

Figure 6 Forest plot: association between hip/groin pain and bent knee fall out range of motion.

8 of 12 Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Figure 7 Forest plot: association between hip/groin pain and strength score for the adductor squeeze test.

Review

Pain provocation tests are used clinically to diagnose hip/groin
pain, and commonly to determine inclusion and exclusion
criteria in research studies. This makes examining their ability to
differentiate somewhat artificial in cases where assignment to
case or control group has used pain provocation tests. We found
one high-quality study that compared the ability of various pain
provocation tests, conducted by a blinded assessor, to differentiate athletes with and without hip/groin pain. \[16\] Another highquality cohort study \[53\] examined pain on the adductor squeeze
test, making meta-analysis possible for this test only. An OR of

–
4.31 (1.86 10) was found on meta-analysis, providing strong
evidence, with a large effect size, that pain on the adductor
squeeze test differentiates athletes with and without current hip/
groin pain. The results of the meta-analysis do not, however,
measure the validity of this test to diagnose any specific individual entity of groin pain. The lack of studies that met the inclusion criteria for this review means that only limited evidence
exists for the diagnostic potential of the single adductor, bilateral adductor, active straight leg raise, pelvic belt, and impingement tests to differentiate athletes with groin pain.
Hip IR measured in 90° flexion was examined in two moderate quality studies. \[33 35\] Meta-analysis found moderate evidence,
with a moderate effect size, that this movement is less in athletes

–
with hip/groin pain; SMD=0.58 (0.14 1.01). There was strong
evidence, with a small effect size, that IR measured in neutral

–
flexion/extension differentiates these groups; SMD=0.42 (0.01
0.83). The actual difference between groups for both these
movements was 3.8 and 3.7°, respectively, which approximates
the reported measurement error. \[15\] The association between a
loss of hip IR and hip/groin pain has been proposed \[54\]\[–\]\[56\] previously, with several possible mechanisms discussed. Bony
impingement is one plausible mechanism and this review provides some support for this mechanism with one cohort study
in which the symptomatic group had clinical and radiological

features of FAI. \[35\] The reduced hip range of motion associated
with athletic groin pain has also been proposed to result from
pain, muscle spasm, or capsular scarring. \[22 55\]

There was conflicting evidence for hip ER; limited evidence
that ER measured in 90° hip flexion does discriminate and
strong evidence that ER measured in neutral flexion/extension
does not discriminate between athletes with and without hip/
groin pain. It has been suggested that the neutral position of the
hip is more reflective of the functional position for the demands
of football. \[15\] The findings of our review suggest that measuring
IR and ER in hip flexion may have greater clinical utility in the
management of hip/groin pain.
The BKFO test has good intratester and intertester reliability
with a measurement error of 2–3 cm. \[15\] Meta-analysis of 2 highquality case–control studies \[5\] 15 found that hip/groin pain
athletes had lower range of motion in this test by 3.6 cm

–
(1.3 5.8 cm), supporting its clinical utility. The predictive ability
of the BKFO test for the development of hip/groin pain has not
been examined and prospective cohort research is recommended.
Hip adduction strength is considered important in hip/groin
pain, and lower scores on the adductor squeeze test at 45°hip
flexion were observed in hip/groin pain athletes in a
meta-analysis of four high-quality case–control studies. \[5 15 30 36\]

The magnitude of the difference between the pain/no pain
groups varied between the studies and there was high statistical
heterogeneity which cannot easily be explained. It is unlikely to
be due to the differing tools of measurement (sphygmomanometer and hand-held dynamometer), as the studies with the most
similar results used one of each tool. The age, duration of symptoms, sport played and diagnostic criteria were also similar
between studies. Therefore, although the heterogeneity is unexplained, each study and the overall pooled result confirm the
clinical utility of the adductor squeeze test. Lower adductor
squeeze test values have been shown to precede the onset of

Figure 8 Forest plot: association between hip/groin pain and presence of bone oedema on MRI.

Figure 9 Forest plot: association between hip/groin pain and presence of bone oedema on MRI following sensitivity analysis.

Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602 9 of 12

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Review

Figure 10 Forest plot: association between hip/groin pain and presence of secondary cleft sign.

groin pain in a small study of Australian rules footballers, \[57\] but
this finding is yet to be tested in other populations. The measurement of adductor squeeze strength is, therefore, recommended in the screening for hip/groin pain in athletes and also
to monitor the treatment response in athletes with current hip/
groin pain.
In single studies, other strength measures (isokinetic hip
extension, adduction and abduction, isometric hip abduction)
did not differentiate between hip/groin pain athletes and controls. \[15 51\] There is limited evidence that hip flexion and hip
flexion/extension ratio did differentiate, with higher hip flexion
strength found in the hip/groin pain group. \[51\] Prospective
studies using varying methods of measurement have identified
lower adduction strength as predictive of athletes who develop
hip/groin pain. \[3 21 23 26\] Our systematic review, therefore, suggests that further investigation with reliable, valid and consistent
measurement methods and instruments is required to determine
which measures of strength, apart from the adductor squeeze
test, differentiate athletes with and without hip/groin pain.
Trunk muscle function was examined in three high-quality
case–control studies \[30 31 50\] using diverse measurement methods,
table 1. Different aspects of trunk muscle function were evaluated: onset timing of the abdominals, eccentric and concentric
abdominal and back strength, and abdominal muscle bulk at
rest and with activity. These studies provide strong evidence
that trunk muscle function is altered in hip/groin pain athletes
and we suggest that it should be assessed and addressed in
management. A randomised controlled trial of an exercise programme that included exercises aimed to improve trunk muscle
function has also been shown to be successful for the management of long-standing groin pain. \[58\] 59 The cross-sectional
nature of the included studies means that it is unknown
whether the altered trunk muscle function precedes or results
from hip/groin pain. Future prospective studies can examine
this question.
Only one low quality study of pubic symphysis X-ray was
included in our review. \[39\] This study found more abnormalities
in the hip/groin pain athletes. However, there was no information available on the activity type or level in the controls, and a
previous study found higher activity levels to be associated with
a greater incidence of X-ray abnormalities. \[60\] It is possible that
the observed abnormalities are a result of activity rather than
related to the presence of hip/groin pain. Therefore, there was
limited evidence to indicate that pubic symphysis X-ray differs
in athletes with hip/groin pain compared to athletic controls.
The utility for diagnosis and management of hip/groin pain in
the athlete is not yet established.
We found moderate evidence that pubic bone oedema differentiates athletes with hip/groin pain from those without pain.
However, a prospective study of 19 elite junior soccer players
found pubic bone marrow oedema in 13 asymptomatic players
at baseline. \[34\] One retrospective study in this review found no
bone oedema in 100 controls, \[38\] including 50 soccer players.
The absence of bone oedema in the 50 soccer player controls

contradicts other studies of asymptomatic footballers in which
54–72% had oedema. \[32 34 40\] Similarly, there was moderate evidence that the presence of a secondary cleft sign differentiates
hip/groin pain athletes from athletes without pain, with an
absence of this sign in 170 asymptomatic control subjects. \[37 38\]

It is worth noting that both these studies were from the same
clinic and may contain the same data set of MRI, thus potentially influencing these findings. Our review found moderate evidence that the presence of bone oedema and the secondary cleft
sign on MRI can differentiate athletes with and without hip and
groin pain. However, research with more rigorous methodology
is required to better understand the clinical and prognostic significance of these findings. A recent review of the radiological
findings in athletic groin pain also found that methodological
quality was lacking and a systematic approach was needed in
future research. \[61\]

The presence of radiological signs of FAI in athletes was
examined in one moderate quality study \[35\] providing limited evidence that these signs can differentiate athletes with hip/groin
pain. There are many studies suggesting that the radiological
features of FAI are highly prevalent in athletic populations, \[41\] 42 62–64 and in athletes with hip/groin pain.65 66

–
However, case control, cross-sectional and prospective studies
that examine FAI in athletes are lacking. There are many
unanswered questions regarding the relationship between radiological and clinical signs of FAI in athletes, and how these relate
to the development of hip/groin pain. Further research in welldescribed groups is required to answer these questions.

Limitations
This systematic review used strict predefined inclusion criteria;
therefore, some studies in the field were not included due to
either low subject numbers or use of non-athletic controls. The
search strategy was comprehensive and included six languages;
however some studies may still have been missed with this strategy. The results of this review are also limited by the current state
of the literature, with inconsistent methods of measurement used
in the assessment, management and prevention of hip/groin pain
in athletes. The current lack of cohort studies with large participant numbers also limits the quality of the data available for synthesis in this review. Most of the athletes included had chronic
groin pain and therefore, the generalisability of these findings to
athletes with acute groin pain is unknown. Furthermore, the low
number of female participants included in the studies potentially
limits the applicability of the findings of this review to female athletes. Only 7 included studies used blinded assessors, suggesting a
potential for bias in many of the studies. It is recommended that
future research include blinded assessors and female participants
where possible.

CONCLUSIONS
This systematic review identified and synthesised data from 17
studies, of which 10 were high quality. The following levels of

10 of 12 Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

evidence were found for various factors able to differentiate athletes with and without hip/groin pain. Strong evidence for:
PROs, pain on the adductor squeeze test, hip IR, bent knee fall
out, adductor squeeze strength and altered trunk muscle function. Moderate evidence for: pubic bone oedema, secondary
cleft sign. Limited evidence for: pain provocation tests (other
than the adductor squeeze), hip ER in 90°flexion, X-ray abnormalities of the pubis, radiological features of FAI and biomarkers of cartilage degradation. There is strong evidence that hip
ER range of motion does not differentiate between these athletes when measured in neutral flexion/extension.
PROs, pain and reduced strength on the adductor squeeze
test, reduced range of motion in internal rotation and bent knee
fall out are the outcome measures that best differentiate athletes
with hip/groin pain from those without pain.

Review

2 Werner J, Hagglund M, Walden M, et al. UEFA injury study: a prospective study of
hip and groin injuries in professional football over seven consecutive seasons.
[Br J Sports Med 2009;43:1036–40.](http://dx.doi.org/10.1136/bjsm.2009.066944)
3 O’Connor DM. Groin injuries in professional rugby league players: a prospective
[study. J Sports Sci 2004;22:629–36.](http://dx.doi.org/10.1080/02640410310001655804)
4 Ryan J, DeBurca N, Mc Creesh K. Risk factors for groin/hip injuries in field-based
[sports: a systematic review. Br J Sports Med 2014;48:1089–96.](http://dx.doi.org/10.1136/bjsports-2013-092263)
5 Nevin F, Delahunt E. Adductor squeeze test values and hip joint range of motion
[in Gaelic football athletes with longstanding groin pain. J Sci Med Sport](http://dx.doi.org/10.1016/j.jsams.2013.04.008)
2014;17:155–9.
6 Feeley BT, Powell JW, Muller MS, et al. Hip injuries and labral tears in the National
[Football League. Am J Sports Med 2008;36:2187–95.](http://dx.doi.org/10.1177/0363546508319898)
7 [Emery CA, Meeuwisse WH. Risk factors for groin injuries in hockey. Med Sci Sports](http://dx.doi.org/10.1097/00005768-200109000-00002)
[Exerc 2001;33:1423–33.](http://dx.doi.org/10.1097/00005768-200109000-00002)
8 Thorborg K, Hölmich P. Advancing hip and groin injury management: from
[eminence to evidence. Br J Sports Med 2013;47:602–5.](http://dx.doi.org/10.1136/bjsports-2012-092090)
9 Bradshaw CJ, Bundy M, Falvey E. The diagnosis of longstanding groin pain: a
[prospective clinical cohort study. Br J Sports Med 2008;42:551–4.](http://dx.doi.org/10.1136/bjsm.2007.039685)
10 Caudill P, Nyland J, Smith C, et al. Sports hernias: a systematic literature review.
[Br J Sports Med 2007;42:954–64.](http://dx.doi.org/10.1136/bjsm.2008.047373)
11 Holmich P, Renstrom PA. Long-standing groin pain in sportspeople falls into three
primary patterns, a “clinical entity” approach: a prospective study of 207 patients\*
[COMMENTARY. Br J Sports Med 2007;41:247–52.](http://dx.doi.org/10.1136/bjsm.2006.033373)
12 Hegedus EJ, Stern B, Reiman MP, et al. A suggested model for physical examination
[and conservative treatment of athletic pubalgia. Phys Ther Sport 2013;14:3–16.](http://dx.doi.org/10.1016/j.ptsp.2012.04.002)
13 Falvey EC, Franklyn-Miller A, McCrory PR. The groin triangle: a patho-anatomical
[approach to the diagnosis of chronic groin pain in athletes. Br J Sports Med](http://dx.doi.org/10.1136/bjsm.2007.042259)
2009;43:213–20.
14 Holmich P. Clinical examination of athletes with groin pain: an intraobserver and
[interobserver reliability study. Br J Sports Med 2004;38:446–51.](http://dx.doi.org/10.1136/bjsm.2003.004754)
15 Malliaras P, Hogan A, Nawrocki A, et al. Hip flexibility and strength measures:
[reliability and association with athletic groin pain. Br J Sports Med 2009;43:739–44.](http://dx.doi.org/10.1136/bjsm.2008.055749)
16 Verrall GM, Slavotinek JP, Barnes PG, et al. Description of pain provocation tests
used for the diagnosis of sports-related chronic groin pain: relationship of tests to
defined clinical (pain and tenderness) and MRI (pubic bone marrow oedema)
[criteria. Scand J Med Sci Sports 2005;15:36–42.](http://dx.doi.org/10.1111/j.1600-0838.2004.00380.x)
17 Engebretsen AH, Myklebust G, Holme I, et al. Intrinsic risk factors for groin injuries
[among male soccer players: a prospective cohort study. Am J Sports Med](http://dx.doi.org/10.1177/0363546510375544)
2010;38:2051–7.
18 Verrall GM, Slavotinek JP, Barnes PG, et al. Hip joint range of motion restriction
[precedes athletic chronic groin injury. J Sci Med Sport 2007;10:463–6.](http://dx.doi.org/10.1016/j.jsams.2006.11.006)
19 Crow JF, Pearce AJ, Veale JP, et al. Hip adductor muscle strength is reduced
preceding and during the onset of groin pain in elite junior Australian football
[players. J Sci Med Sport 2010;13:202–4.](http://dx.doi.org/10.1016/j.jsams.2009.03.007)
20 Witvrouw E, Danneels L, Asselman P, et al. Muscle flexibility as a risk factor for
developing muscle injuries in male professional soccer players a prospective study.
Am J Sports Med 2003;31:41–6.
21 Tyler TF, Nicholas SJ, Campbell RJ, et al. The association of hip strength and
flexibility with the incidence of adductor muscle strains in professional ice hockey
players. Am J Sports Med 2001;29:124–8.
22 Ibrahim A, Murrell GA, Knapman P. Adductor strain and hip range of movement in
male professional soccer players. J Orthop Surg Hong Kong 2007;15:46–9.
23 [Arnason A. Risk Factors for Injuries in Football. Am J Sports Med 2004;32:5S–16.](http://dx.doi.org/10.1177/0363546503258912)
24 Maffey L, Emery C. What are the risk factors for groin strain injury in sport?
[Sports Med 2007;37:881–94.](http://dx.doi.org/10.2165/00007256-200737100-00004)
25 Tyler TF, Nicholas SJ, Campbell RJ, et al. The effectiveness of a preseason exercise
program to prevent adductor muscle strains in professional ice hockey players.
Am J Sports Med 2002;30:680–3.
26 Engebretsen AH, Myklebust G, Holme I, et al. Prevention of injuries among male
soccer players: a prospective, randomized intervention study targeting players with
[previous injuries or reduced function. Am J Sports Med 2008;36:1052–60.](http://dx.doi.org/10.1177/0363546508314432)
27 Junge A, Rösch D, Peterson L, et al. Prevention of soccer injuries:
a prospective intervention study in youth amateur players. Am J Sports Med
2002;30:652–9.
28 Hölmich P, Larsen K, Krogsgaard K, et al. Exercise program for prevention of groin
pain in football players: a cluster-randomized trial: Exercise program for prevention
[of groin pain in football players. Scand J Med Sci Sports 2010;20:814–21.](http://dx.doi.org/10.1111/j.1600-0838.2009.00998.x)
29 Thorborg K, Holmich P, Christensen R, et al. The Copenhagen Hip and Groin
Outcome Score (HAGOS): development and validation according to the COSMIN
[checklist. Br J Sports Med 2011;45:478–91.](http://dx.doi.org/10.1136/bjsm.2010.080937)
30 Jansen J, Weir A, Dénis R, et al. Resting thickness of transversus abdominis is
[decreased in athletes with longstanding adduction-related groin pain. Man Ther](http://dx.doi.org/10.1016/j.math.2009.11.001)
2010;15:200–5.
31 Cowan SM, Schache AG, Brukner P, et al. Delayed onset of transversus abdominus
[in long-standing groin pain. Med Sci Sports Exerc 2004;36:2040–5.](http://dx.doi.org/10.1249/01.MSS.0000147587.81762.44)
32 Verrall GM, Slavotinek JP, Fon GT. Incidence of pubic bone marrow oedema in
[Australian rules football players: relation to groin pain. Br J Sports Med](http://dx.doi.org/10.1136/bjsm.35.1.28)
2001;35:28–33.

Acknowledgements The authors would like to thank Wichor Bramer for his
assistance with the literature search for this study.

Contributors ABM, RA, AW and KMC planned the manuscript. All authors
contributed to the interpretation of the data, writing, editing and approval of the
manuscript.

Competing interests None declared.

Provenance and peer review Not commissioned; externally peer reviewed.

Open Access This is an Open Access article distributed in accordance with the
Creative Commons Attribution Non Commercial (CC BY-NC 4.0) license, which
permits others to distribute, remix, adapt, build upon this work non-commercially,
and license their derivative works on different terms, provided the original work is
[properly cited and the use is non-commercial. See: http://creativecommons.org/](http://creativecommons.org/licenses/by-nc/4.0/)
[licenses/by-nc/4.0/](http://creativecommons.org/licenses/by-nc/4.0/)

REFERENCES

1 Orchard J, Seward H. Epidemiology of injuries in the Australian Football League,
[seasons 1997–2000. Br J Sports Med 2002;36:39–44.](http://dx.doi.org/10.1136/bjsm.36.1.39)

Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602 11 of 12

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

Review

33 Verrall GM, Hamilton IA, Slavotinek JP, et al. Hip joint range of motion reduction in
[sports-related chronic groin injury diagnosed as pubic bone stress injury. J Sci Med](<http://dx.doi.org/10.1016/S1440-2440(05)80027-1>)
[Sport 2005;8:77–84.](<http://dx.doi.org/10.1016/S1440-2440(05)80027-1>)
34 Lovell G, Galloway H, Hopkins W, et al. Osteitis pubis and assessment of bone
marrow edema at the pubic symphysis with MRI in an elite junior male soccer
[squad. Clin J Sport Med 2006;16:117–22.](http://dx.doi.org/10.1097/00042752-200603000-00006)
35 Siebenrock KA, Kaschka I, Frauchiger L, et al. Prevalence of cam-type deformity and
[hip pain in elite ice hockey players before and after the end of growth. Am J Sports](http://dx.doi.org/10.1177/0363546513497564)
[Med 2013;41:2308–13.](http://dx.doi.org/10.1177/0363546513497564)
36 Mens J, Inklaar H, Koes BW, et al. A new view on adduction-related groin pain.
[Clin J Sport Med 2006;16:15–19.](http://dx.doi.org/10.1097/01.jsm.0000180869.37673.7b)
37 Brennan D, O’Connell MJ, Ryan M, et al. Secondary cleft sign as a marker of injury
[in athletes with groin pain: MR image appearance and interpretation1. Radiology](http://dx.doi.org/10.1148/radiol.2351040045)
2005;235:162–7.
38 Cunningham PM, Brennan D, O’Connell M, et al. Patterns of bone and soft-tissue
[injury at the symphysis pubis in soccer players: observations at MRI. Am J](http://dx.doi.org/10.2214/AJR.06.0051)
[Roentgenol 2007;188:W291–6.](http://dx.doi.org/10.2214/AJR.06.0051)
39 Besjakov J, von Scheele C, Ekberg O, et al. Grading scale of radiographic findings in
the public bone and symphysis in athletes. Acta Radiol 2003;44:79–83.
40 Paajanen H, Hermunen H, Karonen J. Pubic magnetic resonance imaging
findings in surgically and conservatively treated athletes with osteitis pubis
[compared to asymptomatic athletes during heavy training. Am J Sports Med](http://dx.doi.org/10.1177/0363546507305454)
2007;36:117–21.
41 Mariconda M, Cozzolino A, Pietto F, et al. Radiographic findings of
[femoroacetabular impingement in capoeira players. Knee Surg Sports Traumatol](http://dx.doi.org/10.1007/s00167-014-2850-7)
[Arthrosc 2014;22:874–81.](http://dx.doi.org/10.1007/s00167-014-2850-7)
42 Larson CM, Sikka RS, Sardelli MC, et al. Increasing alpha angle is predictive of
athletic-related “Hip” and “Groin” pain in collegiate National Football League
[prospects. Arthrosc J Arthrosc Relat Surg 2013;29:405–10.](http://dx.doi.org/10.1016/j.arthro.2012.10.024)
43 Downs SH, Black N. The feasibility of creating a checklist for the assessment of the
methodological quality both of randomised and non-randomised studies of health
[care interventions. J Epidemiol Community Health 1998;52:377–84.](http://dx.doi.org/10.1136/jech.52.6.377)
44 Irving DB, Cook JL, Menz HB. Factors associated with chronic plantar heel pain:
[a systematic review. J Sci Med Sport 2006;9:11–22.](http://dx.doi.org/10.1016/j.jsams.2006.02.004)
45 Munn J, Sullivan SJ, Schneiders AG. Evidence of sensorimotor deficits in functional
[ankle instability: a systematic review with meta-analysis. J Sci Med Sport](http://dx.doi.org/10.1016/j.jsams.2009.03.004)
2010;13:2–12.
46 Cohen J. Statistical power analysis for the behavioral sciences.2nd edn. Hillsdale,
NJ, USA: Lawrence Erlbaum Associates, 1988.
47 Coombes BK, Bisset L, Vicenzino B. Efficacy and safety of corticosteroid injections
and other injections for management of tendinopathy: a systematic review of
[randomised controlled trials. Lancet 2010;376:1751–67.](<http://dx.doi.org/10.1016/S0140-6736(10)61160-9>)
48 Van Tulder M, Furlan A, Bombardier C, et al. Updated method guidelines for
systematic reviews in the Cochrane Collaboration Back Review Group. Spine
2003;28:1290–9.

49 Jansen JACG, Mens JMA, Backx FJG, et al. Diagnostics in athletes with
[long-standing groin pain: diagnostics in athletes with groin pain. Scand J Med Sci](http://dx.doi.org/10.1111/j.1600-0838.2008.00848.x)
[Sports 2008;18:679–90.](http://dx.doi.org/10.1111/j.1600-0838.2008.00848.x)
50 Sayed Mohammad W, Ragaa Abdelraouf O, Abdel-aziem AA. Concentric and
eccentric strength of trunk muscles in osteitis pubis soccer players. J Back
Musculoskelet Rehabil 2014;27:147–52.
51 Mohammad WS, Abdelraouf OR, Elhafez SM, et al. Isokinetic imbalance
[of hip muscles in soccer players with osteitis pubis. J Sports Sci 2014;32:934–9.](http://dx.doi.org/10.1080/02640414.2013.868918)
52 Bedi A, Lynch EB, Sibilsky Enselman ER, et al. Elevation in circulating biomarkers of
cartilage damage and inflammation in athletes with femoroacetabular impingement.
[Am J Sports Med 2013;41:2585–90.](http://dx.doi.org/10.1177/0363546513499308)
53 Taylor CJ, Pizzari T, Ames N, et al. Groin pain and hip range of motion is different
[in indigenous compared to non-indigenous young Australian football players. J Sci](http://dx.doi.org/10.1016/j.jsams.2011.02.002)
[Med Sport 2011;14:283–6.](http://dx.doi.org/10.1016/j.jsams.2011.02.002)
54 Williams JG. Limitation of hip joint movement as a factor in traumatic osteitis pubis.
[Br J Sports Med 1978;12:129–33.](http://dx.doi.org/10.1136/bjsm.12.3.129)
55 [Fricker PA, Taunton JE, Ammann W. Osteitis pubis in athletes. Sports Med](http://dx.doi.org/10.2165/00007256-199112040-00005)
1991;12:266–79.
56 Philippon MJ, Maxwell RB, Johnston TL, et al. Clinical presentation of femoroacetabular
[impingement. Knee Surg Sports Traumatol Arthrosc 2007;15:1041–7.](http://dx.doi.org/10.1007/s00167-007-0348-2)
57 [Crowe RJ. A comparative study of the results of surgery on the sporting groin. J Sci](<http://dx.doi.org/10.1016/S1440-2440(99)80143-1>)
[Med Sport 1999;2:97.](<http://dx.doi.org/10.1016/S1440-2440(99)80143-1>)
58 Hölmich P, Uhrskou P, Ulnits L, et al. Effectiveness of active physical training as
treatment for long-standing adductor-related groin pain in athletes: randomised
[trial. Lancet 1999;353:439–43.](<http://dx.doi.org/10.1016/S0140-6736(98)03340-6>)
59 Holmich P, Nyvold P, Larsen K. Continued significant effect of physical training as
treatment for overuse injury: 8- to 12-year outcome of a randomized clinical trial.
[Am J Sports Med 2011;39:2447–51.](http://dx.doi.org/10.1177/0363546511416075)
60 [Harris NH, Murray RO. Lesions of the symphysis in athletes. Br Med J 1974;4:211.](http://dx.doi.org/10.1136/bmj.4.5938.211)
61 Branci S, Thorborg K, Nielsen MB, et al. Radiological findings in symphyseal and
[adductor-related groin pain in athletes: a critical review of the literature. Br J Sports](http://dx.doi.org/10.1136/bjsports-2012-091905)
[Med 2013;47:611–19.](http://dx.doi.org/10.1136/bjsports-2012-091905)
62 Agricola R, Bessems JHJM, Ginai AZ, et al. The development of cam-type deformity
[in adolescent and young male soccer players. Am J Sports Med](http://dx.doi.org/10.1177/0363546512438381)
2012;40:1099–106.
63 Johnson AC, Shaman MA, Ryan TG. Femoroacetabular Impingement in Former
[High-Level Youth Soccer Players. Am J Sports Med 2012;40:1342–6.](http://dx.doi.org/10.1177/0363546512439287)
64 Gerhardt MB, Romero AA, Silvers HJ, et al. The prevalence of radiographic hip
[abnormalities in elite soccer players. Am J Sports Med 2012;40:584–8.](http://dx.doi.org/10.1177/0363546511432711)
65 Weir A, de Vos RJ, Moen M, et al. Prevalence of radiological signs of
femoroacetabular impingement in patients presenting with long-standing
[adductor-related groin pain. Br J Sports Med 2009;45:6–9.](http://dx.doi.org/10.1136/bjsm.2009.060434)
66 Holmich P, Thorborg K, Nyvold P, et al. Does bony hip morphology affect the
outcome of treatment for patients with adductor-related groin pain? Outcome 10
[years after baseline assessment. Br J Sports Med 2014;48:1240–4.](http://dx.doi.org/10.1136/bjsports-2013-092478)

12 of 12 Mosler AB, et al. Br J Sports Med 2015;49:810. doi:10.1136/bjsports-2015-094602

[Downloaded from http://bjsm.bmj.com/ on June 15, 2015 - Published by group.bmj.com](http://bjsm.bmj.com/)

## **Which factors differentiate athletes with** **hip/groin pain from those without? A** **systematic review with meta-analysis**

Andrea B Mosler, Rintje Agricola, Adam Weir, Per Hölmich and Kay M
Crossley

_Br J Sports Med_ 2015 49: 810
doi: 10.1136/bjsports-2015-094602

Updated information and services can be found at:
**[http://bjsm.bmj.com/content/49/12/810](http://bjsm.bmj.com/content/49/12/810)**

_These include:_

**Supplementary**
**Material**

**References**

**Open Access**

**Email alerting**
**service**

Supplementary material can be found at:
**[http://bjsm.bmj.com/content/suppl/2015/05/27/49.12.810.DC1.html](http://bjsm.bmj.com/content/suppl/2015/05/27/49.12.810.DC1.html)**

This article cites 65 articles, 31 of which you can access for free at:
**[http://bjsm.bmj.com/content/49/12/810](http://bjsm.bmj.com/content/49/12/810#BIBL)** #BIBL

This is an Open Access article distributed in accordance with the Creative
Commons Attribution Non Commercial (CC BY-NC 4.0) license, which
permits others to distribute, remix, adapt, build upon this work
non-commercially, and license their derivative works on different terms,
provided the original work is properly cited and the use is
non-commercial. See: [http://creativecommons.org/licenses/by-nc/4.0/](http://creativecommons.org/licenses/by-nc/4.0/)

Receive free email alerts when new articles cite this article. Sign up in the
box at the top right corner of the online article.

**Topic** Articles on similar topics can be found in the following collections
**Collections**

[BJSM Reviews with MCQs (88)](http://bjsm.bmj.com//cgi/collection/bjsm_education)

[Open access (178)](http://bjsm.bmj.com//cgi/collection/unlocked)

**Notes**

To request permissions go to:
**[http://group.bmj.com/group/rights-licensing/permissions](http://group.bmj.com/group/rights-licensing/permissions)**

To order reprints go to:
**[http://journals.bmj.com/cgi/reprintform](http://journals.bmj.com/cgi/reprintform)**

To subscribe to BMJ go to:
**[http://group.bmj.com/subscribe/](http://group.bmj.com/subscribe/)**
